## cdist-type__yum_repo(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__yum_repo - manage yum repositories

## 2. DESCRIPTION

For all undocumented parameters see yum.conf(5).

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

state
  present or absent. Defaults to present
repositoryid
  Defaults to __object_id.
name , baseurl
  Can be specified multiple times.
metalink , mirrorlist , gpgkey
  Can be specified multiple times.
gpgcakey , gpgcheck , exclude , includepkgs , failovermethod , timeout , http_caching , retries , throttle , bandwidth , sslcacert , sslverify , sslclientcert , sslclientkey , ssl_check_cert_permissions , metadata_expire , mirrorlist_expire , proxy , proxy_username , proxy_password , username , password , cost
  BOOLEAN PARAMETERS

    enabled::
    repo_gpgcheck::
    disablegroups::
       ! enablegroups
    keepalive::
    skip_if_unavailable::

    EXAMPLES

    __yum_repo epel \
       --name 'Extra Packages for Enterprise Linux 6 - $basearch' \
       --mirrorlist 'https://mirrors.fedoraproject.org/metalink?repo=epel-$releasever&arch=$basearch' \
       --failovermethod priority \
       --enabled \
       --gpgcheck 1 \
       --gpgkey https://fedoraproject.org/static/0608B895.txt

## 5. SEE ALSO

- cdist-type(7)

## 6. COPYING

Copyright (C) 2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).